amber/caa_record

Types

pub type CaaRecord {
  CaaRecord(critical: Bool, tag: String, value: String)
}

Constructors

  • CaaRecord(critical: Bool, tag: String, value: String)

    Arguments

    critical

    If true, indicates that the corresponding property tag must be understood if the semantics of the CAA record are to be correctly interpreted by an issuer.

    Issuers must not issue certificates for a domain if the relevant CAA Resource Record set contains unknown property tags that have critical set.

    tag

    A string that represents the identifier of the property represented by the record.

    value

    The value associated with the tag.

Search Document