amber/conn/tls_conn

Types

pub type TlsConn

Values

pub fn handshake(
  conn: TlsConn,
) -> promise.Promise(
  Result(tls_handshake_info.TlsHandshakeInfo, error.Error),
)

Runs the client or server handshake protocol to completion if that has not happened yet. Calling this method is optional; the TLS handshake will be completed automatically as soon as data is sent or received.

pub fn to_conn(conn: TlsConn) -> conn.Conn

Converts a TlsConn to a Conn for use with generic connection functions.

Search Document