amber/inspect_option

Types

Option which can be specified when performing amber.inspect.

pub type InspectOption {
  Colors
  Compact(Bool)
  Depth(Int)
  BreakLength(Int)
  EscapeSequences(Bool)
  IterableLimit(Int)
  ShowProxy
  Sorted
  TrailingComma
  Getters
  ShowHidden
  StrAbbreviateSize(Int)
}

Constructors

  • Colors

    Stylize output with ANSI colors.

  • Compact(Bool)

    Try to fit more than one entry of a collection on the same line.

  • Depth(Int)

    Traversal depth for nested objects.

  • BreakLength(Int)

    The maximum length for an inspection to take up a single line.

  • EscapeSequences(Bool)

    Whether or not to escape sequences.

  • IterableLimit(Int)

    The maximum number of iterable entries to print.

  • ShowProxy

    Show a Proxy’s target and handler.

  • Sorted

    Sort Object, Set and Map entries by key.

  • TrailingComma

    Add a trailing comma for multiline collections.

  • Getters

    Evaluate the result of calling getters.

  • ShowHidden

    Show an object’s non-enumerable properties.

  • StrAbbreviateSize(Int)

    The maximum number of characters to print for a string.

Search Document