amber/naptr_record

Types

pub type NaptrRecord {
  NaptrRecord(
    order: Int,
    preference: Int,
    flags: String,
    services: String,
    regexp: String,
    replacement: String,
  )
}

Constructors

  • NaptrRecord(
      order: Int,
      preference: Int,
      flags: String,
      services: String,
      regexp: String,
      replacement: String,
    )

    Arguments

    order

    The order in which NAPTR records must be processed to ensure the correct ordering of rules.

    preference

    The preference used to select between NAPTR records with equal order values. Lower values are preferred.

    flags

    Flags that control aspects of the rewriting and interpretation of the fields in the record (e.g., “u”, “s”, “a”, “p”).

    services

    The service(s) available down this rewrite path.

    regexp

    A regular expression applied to the original string from the client to construct the next domain name to look up.

    replacement

    The next domain name to query if the flags field is empty. Used as an alternative to the regexp field.

Search Document