amber/tls_certified_key_pem

Types

Provides certified key material from strings. The key material is provided in PEM-format (Privacy Enhanced Mail, https://www.rfc-editor.org/rfc/rfc1422) which can be identified by having -----BEGIN----- and -----END----- markers at the beginning and end of the strings. This type of key is not compatible with DER-format keys which are binary.

Deno supports RSA, EC, and PKCS8-format keys.

pub type TlsCertifiedKeyPem {
  TlsCertifiedKeyPem(key: String, cert: String)
}

Constructors

  • TlsCertifiedKeyPem(key: String, cert: String)

    Arguments

    key

    Private key in PEM format. RSA, EC, and PKCS8-format keys are supported.

    cert

    Certificate chain in PEM format.

Search Document