amber/conn/tls_conn
Types
Values
pub fn handshake(
conn: TlsConn,
) -> promise.Promise(
Result(tls_handshake_info.TlsHandshakeInfo, error.Error),
)
Runs the client or server handshake protocol to completion if that has not happened yet. Calling this method is optional; the TLS handshake will be completed automatically as soon as data is sent or received.