amber/inspect_option
Types
Option which can be specified when performing
amber.inspect.
pub type InspectOption {
Colors
Compact(Bool)
Depth(Int)
BreakLength(Int)
EscapeSequences(Bool)
IterableLimit(Int)
ShowProxy
Sorted
TrailingComma
Getters
ShowHidden
StrAbbreviateSize(Int)
}
Constructors
-
ColorsStylize output with ANSI colors.
-
Compact(Bool)Try to fit more than one entry of a collection on the same line.
-
Depth(Int)Traversal depth for nested objects.
-
BreakLength(Int)The maximum length for an inspection to take up a single line.
-
EscapeSequences(Bool)Whether or not to escape sequences.
-
IterableLimit(Int)The maximum number of iterable entries to print.
-
ShowProxyShow a Proxy’s target and handler.
-
SortedSort Object, Set and Map entries by key.
-
TrailingCommaAdd a trailing comma for multiline collections.
-
GettersEvaluate the result of calling getters.
-
ShowHiddenShow an object’s non-enumerable properties.
-
StrAbbreviateSize(Int)The maximum number of characters to print for a string.