amber/listener
Types
Values
pub fn accept(
listener: Listener,
) -> promise.Promise(Result(tcp_conn.TcpConn, error.Error))
Waits for and resolves to the next connection to the Listener.
pub fn close(listener: Listener) -> Result(Nil, error.Error)
Close closes the listener. Any pending accept promises will be rejected with errors.
pub fn ref(listener: Listener) -> Nil
Make the listener block the event loop from finishing.