amber/resolve_dns_option
Types
pub type ResolveDnsOption {
NameServer(ip_addr: String)
NameServerWithPort(ip_addr: String, port: Int)
Signal(abort_signal.AbortSignal)
}
Constructors
-
NameServer(ip_addr: String)The name server to be used for lookups. If not specified, defaults to the system configuration. For example
/etc/resolv.confon Unix-like systems. -
NameServerWithPort(ip_addr: String, port: Int)The name server to be used for lookups, with a specific port.
-
Signal(abort_signal.AbortSignal)An abort signal to allow cancellation of the DNS resolution operation. If the signal becomes aborted the
resolve_dnsoperation will be stopped and the promise returned will be rejected with an AbortError.