amber/soa_record
Types
pub type SoaRecord {
SoaRecord(
mname: String,
rname: String,
serial: Int,
refresh: Int,
retry: Int,
expire: Int,
minimum: Int,
)
}
Constructors
-
SoaRecord( mname: String, rname: String, serial: Int, refresh: Int, retry: Int, expire: Int, minimum: Int, )Arguments
- mname
-
The domain name of the primary name server for this zone.
- rname
-
The email address of the administrator responsible for this zone, encoded in DNS name format (e.g., “admin.example.com” represents “admin@example.com”).
- serial
-
The version number of the original copy of the zone. Incremented when the zone data changes.
- refresh
-
The time interval (in seconds) before the zone should be refreshed by secondary servers.
- retry
-
The time interval (in seconds) before a failed refresh should be retried.
- expire
-
The upper limit (in seconds) on the time interval that can elapse before the zone is no longer authoritative.
- minimum
-
The minimum TTL (in seconds) that should be exported with any record from this zone.