amber/start_tls_option

Types

pub type StartTlsOption {
  Hostname(String)
  CaCerts(List(String))
  AlpnProtocols(List(String))
}

Constructors

  • Hostname(String)

    A literal IP address or host name that can be resolved to an IP address.

  • CaCerts(List(String))

    A list of root certificates that will be used in addition to the default root certificates to verify the peer’s certificate.

    Must be in PEM format.

  • AlpnProtocols(List(String))

    Application-Layer Protocol Negotiation (ALPN) protocols to announce to the client. If not specified, no ALPN extension will be included in the TLS handshake.

Search Document