amber/tls_listener
Types
Specialized listener that accepts TLS connections.
pub type TlsListener
Values
pub fn accept(
listener: TlsListener,
) -> promise.Promise(Result(tls_conn.TlsConn, error.Error))
Waits for and resolves to the next connection to the TlsListener.
pub fn addr(of listener: TlsListener) -> net_addr.NetAddr
Return the address of the TlsListener.
pub fn close(listener: TlsListener) -> Result(Nil, error.Error)
Close closes the listener. Any pending accept promises will be rejected with errors.
pub fn ref(listener: TlsListener) -> Nil
Make the listener block the event loop from finishing.
pub fn unref(listener: TlsListener) -> Nil
Make the listener not block the event loop from finishing.