amber/web_socket_upgrade
Types
The object returned from amber.upgrade_web_socket.
pub type WebSocketUpgrade {
WebSocketUpgrade(
response: response.Response,
socket: web_socket.WebSocket,
)
}
Constructors
-
WebSocketUpgrade( response: response.Response, socket: web_socket.WebSocket, )Arguments
- response
-
The response object that represents the HTTP response to the client, which should be used to respond to the request for the upgrade to be successful.
- socket
-
The
WebSocketinterface to communicate to the client via a web socket.